geochemistrypi.data\_mining.model.func package
==============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   geochemistrypi.data_mining.model.func.algo_abnormaldetection
   geochemistrypi.data_mining.model.func.algo_classification
   geochemistrypi.data_mining.model.func.algo_clustering
   geochemistrypi.data_mining.model.func.algo_decomposition
   geochemistrypi.data_mining.model.func.algo_regression

Module contents
---------------

.. automodule:: geochemistrypi.data_mining.model.func
   :members:
   :undoc-members:
   :show-inheritance:
